==> minitube-src-0.5.tar.gz: minitube/locale/pl_PL.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl_PL">
<defaultcodec>UTF-8</defaultcodec>
<context>
    <name>AboutView</name>
    <message>
        <source>There&apos;s life outside the browser!</source>
        <translation>Istnieje życie poza przeglądarką internetową!</translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation>Wersja %1</translation>
    </message>
    <message>
        <source>This is a &quot;Technology Preview&quot; release, do not expect it to be perfect.</source>
        <translation>To jest wydanie &quot;Technology Preview&quot; więc nie spodziewaj się, że będzie idealne.</translation>
    </message>
    <message>
        <source>Report bugs and send in your ideas to %1</source>
        <translation>Raporty o błędach oraz pomysłach ślij na adres %1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 to darmowe oprogramowanie ale jego tworzenie zabiera cenny czas.</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate via PayPal&lt;/a&gt; to support the continued development of %2.</source>
        <translation>Proszę &lt;a href=&apos;%1&apos;&gt;wspomóż finansowo przez PayPal&lt;/a&gt; prace nad programem %2.</translation>
    </message>
    <message>
        <source>Icon designed by %1.</source>
        <translation>Ikony stworzone przez %1.</translation>
    </message>
    <message>
        <source>Compact mode contributed by %1.</source>
        <translation>Tryb kompaktowy dzięĸi %1.</translation>
    </message>
    <message>
        <source>Translated by %1</source>
        <translation>Udział w tłumaczeniu mają: %1</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>Program wydany na licencji &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Zamknij</translation>
    </message>
    <message>
        <source>About</source>
        <translation>O programie</translation>
    </message>
    <message>
        <source>What you always wanted to know about %1 and never dared to ask</source>
        <translation>To co zawsze chciałeś wiedzieć o %1 ale bałeś się zapytać</translation>
    </message>
</context>
<context>
    <name>ClearButton</name>
    <message>
        <source>Clear</source>
        <translation>Wyczyść</translation>
    </message>
</context>
<context>
    <name>ListModel</name>
    <message>
        <source>Searching...</source>
        <translation>Szukanie...</translation>
    </message>
    <message>
        <source>Show %1 More</source>
        <translation>Pokaż następne %1</translation>
    </message>
    <message>
        <source>No videos</source>
        <translation>Brak plików wideo</translation>
    </message>
    <message>
        <source>No more videos</source>
        <translation>Nie ma więcej filmów</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Back</source>
        <translation>Powrót</translation>
    </message>
    <message>
        <source>Go to the previous view</source>
        <translation>Wróć do poprzedniego filmu</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation></translation>
    </message>
    <message>
        <source>Stop playback and go back to the search view</source>
        <translation>Zatrzymaj odtwarzanie i wróć do wyszukiwania</translation>
    </message>
    <message>
        <source>S&amp;kip</source>
        <translation type="unfinished">Następny</translation>
    </message>
    <message>
        <source>Skip to the next video</source>
        <translation>Pomiń i włącz następny film</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pauza</translation>
    </message>
    <message>
        <source>Pause playback</source>
        <translation>Wstrzymaj odtwarzanie</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>Pełny &amp;Ekran</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>Włącz widok pełnoekranowy</translation>
    </message>
    <message>
        <source>&amp;Compact mode</source>
        <translation>Tryb kompaktowy</translation>
    </message>
    <message>
        <source>Hide the playlist and the toolbar</source>
        <translation>Ukryj listę odtwarzania i pasek narzędziowy</translation>
    </message>
    <message>
        <source>&amp;YouTube</source>
        <translation></translation>
    </message>
    <message>
        <source>Open the YouTube video page</source>
        <translation>Otwórz film YouTube w przeglądarce</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>Usuń</translation>
    </message>
    <message>
        <source>Remove the selected videos from the playlist</source>
        <translation>Usuń zaznaczone filmy z listy odtwarzania</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>Przes&amp;uń w górę</translation>
    </message>
    <message>
        <source>Move up the selected videos in the playlist</source>
        <translation>Przesuń do góry zaznaczone filmy na liście odtwarzania</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>Przesuń w &amp;dół</translation>
    </message>
    <message>
        <source>Move down the selected videos in the playlist</source>
        <translation>Przesuń na dół zaznaczone filmy na liście odtwarzania</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>Wyjdź</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation></translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>Na razie</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>Strona domo&amp;wa</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation type="unfinished">Strona domowa %1</translation>
    </message>
    <message>
        <source>&amp;Donate via PayPal</source>
        <translation>&amp;Dotacja dla twórcy przez PayPal</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>Proszę, wspomóż finansowo prace na %1</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>O progr&amp;amie</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>Info o %1</translation>
    </message>
    <message>
        <source>&amp;Search</source>
        <translation>Szukaj</translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation>Program</translation>
    </message>
    <message>
        <source>&amp;Playlist</source>
        <translation>Lista odtwarzania</translation>
    </message>
    <message>
        <source>&amp;Video</source>
        <translation>Film</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>Pomoc</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Otwieranie %1</translation>
    </message>
    <message>
        <source>Fatal error: %1</source>
        <translation>Fatalny błąd: %1</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Błąd: %1</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>&amp;Odtwarzaj</translation>
    </message>
    <message>
        <source>Resume playback</source>
        <translation>Wznów odtwarzanie</translation>
    </message>
    <message>
        <source>Exit &amp;Full Screen</source>
        <translation>Wyłącz &amp;pełny ekran</translation>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>Most relevant</source>
        <translation>Najbardziej trafne</translation>
    </message>
    <message>
        <source>Most recent</source>
        <translation>Najnowsze</translation>
    </message>
    <message>
        <source>Most viewed</source>
        <translation>Najpopularniejsze</translation>
    </message>
    <message>
        <source>You&apos;re watching &quot;%1&quot;</source>
        <translation>Oglądasz &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>PrettyItemDelegate</name>
    <message>
        <source>%1 views</source>
        <translation>%1 wyświetleń</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Szukaj</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>Witaj w &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
    </message>
    <message>
        <source>Enter a keyword to start watching videos.</source>
        <translation>Wpisz szukane słowo i zacznij oglądać filmy.</translation>
    </message>
    <message>
        <source>Watch</source>
        <translation>Wyświetl</translation>
    </message>
    <message>
        <source>Recent keywords</source>
        <translation>Ostatnio szukane</translation>
    </message>
    <message>
        <source>A new version of %1 is available. Please &lt;a href=&apos;%2&apos;&gt;update to version %3&lt;/a&gt;</source>
        <translation>Nowa wersja %1 jest dostępna. Proszę &lt;a href=&apos;%2&apos;&gt; zaktualizuj do wersji %3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Make yourself comfortable</source>
        <translation>Usiądź wygodnie</translation>
    </message>
</context>
<context>
    <name>SettingsView</name>
    <message>
        <source>Preferences</source>
        <translation>Opcje</translation>
    </message>
</context>
</TS>

==> minitube-src-0.6.1.tar.gz: minitube/locale/pl_PL.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl_PL">
<defaultcodec>UTF-8</defaultcodec>
<context>
    <name>AboutView</name>
    <message>
        <source>There&apos;s life outside the browser!</source>
        <translation>Istnieje życie poza przeglądarką internetową!</translation>
    </message>
    <message>
        <source>Version %1</source>
        <translation>Wersja %1</translation>
    </message>
    <message>
        <source>This is a &quot;Technology Preview&quot; release, do not expect it to be perfect.</source>
        <translation>To jest wydanie &quot;Technology Preview&quot; więc nie spodziewaj się, że będzie idealne.</translation>
    </message>
    <message>
        <source>Report bugs and send in your ideas to %1</source>
        <translation>Raporty o błędach oraz pomysłach ślij na adres %1</translation>
    </message>
    <message>
        <source>%1 is Free Software but its development takes precious time.</source>
        <translation>%1 to darmowe oprogramowanie ale jego tworzenie zabiera cenny czas.</translation>
    </message>
    <message>
        <source>Please &lt;a href=&apos;%1&apos;&gt;donate via PayPal&lt;/a&gt; to support the continued development of %2.</source>
        <translation>Proszę &lt;a href=&apos;%1&apos;&gt;wspomóż finansowo przez PayPal&lt;/a&gt; prace nad programem %2.</translation>
    </message>
    <message>
        <source>Icon designed by %1.</source>
        <translation>Ikony stworzone przez %1.</translation>
    </message>
    <message>
        <source>Compact mode contributed by %1.</source>
        <translation>Tryb kompaktowy dzięĸi %1.</translation>
    </message>
    <message>
        <source>Translated by %1</source>
        <translation>Udział w tłumaczeniu mają: %1</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
        <translation>Program wydany na licencji &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Zamknij</translation>
    </message>
    <message>
        <source>About</source>
        <translation>O programie</translation>
    </message>
    <message>
        <source>What you always wanted to know about %1 and never dared to ask</source>
        <translation>To co zawsze chciałeś wiedzieć o %1 ale bałeś się zapytać</translation>
    </message>
</context>
<context>
    <name>ClearButton</name>
    <message>
        <source>Clear</source>
        <translation>Wyczyść</translation>
    </message>
</context>
<context>
    <name>ListModel</name>
    <message>
        <source>Searching...</source>
        <translation>Szukanie...</translation>
    </message>
    <message>
        <source>Show %1 More</source>
        <translation>Pokaż następne %1</translation>
    </message>
    <message>
        <source>No videos</source>
        <translation>Brak plików wideo</translation>
    </message>
    <message>
        <source>No more videos</source>
        <translation>Nie ma więcej filmów</translation>
    </message>
</context>
<context>
    <name>LoadingWidget</name>
    <message>
        <source>Error</source>
        <translation>Błąd</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>&amp;Back</source>
        <translation>Powrót</translation>
    </message>
    <message>
        <source>Go to the previous view</source>
        <translation>Wróć do poprzedniego filmu</translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation></translation>
    </message>
    <message>
        <source>Stop playback and go back to the search view</source>
        <translation>Zatrzymaj odtwarzanie i wróć do wyszukiwania</translation>
    </message>
    <message>
        <source>S&amp;kip</source>
        <translation>Następny</translation>
    </message>
    <message>
        <source>Skip to the next video</source>
        <translation>Pomiń i włącz następny film</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pauza</translation>
    </message>
    <message>
        <source>Pause playback</source>
        <translation>Wstrzymaj odtwarzanie</translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>Pełny &amp;Ekran</translation>
    </message>
    <message>
        <source>Go full screen</source>
        <translation>Włącz widok pełnoekranowy</translation>
    </message>
    <message>
        <source>&amp;Compact mode</source>
        <translation>Tryb kompaktowy</translation>
    </message>
    <message>
        <source>Hide the playlist and the toolbar</source>
        <translation>Ukryj listę odtwarzania i pasek narzędziowy</translation>
    </message>
    <message>
        <source>&amp;YouTube</source>
        <translation></translation>
    </message>
    <message>
        <source>Open the YouTube video page</source>
        <translation>Otwórz film YouTube w przeglądarce</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>Usuń</translation>
    </message>
    <message>
        <source>Remove the selected videos from the playlist</source>
        <translation>Usuń zaznaczone filmy z listy odtwarzania</translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation>Przes&amp;uń w górę</translation>
    </message>
    <message>
        <source>Move up the selected videos in the playlist</source>
        <translation>Przesuń do góry zaznaczone filmy na liście odtwarzania</translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation>Przesuń w &amp;dół</translation>
    </message>
    <message>
        <source>Move down the selected videos in the playlist</source>
        <translation>Przesuń na dół zaznaczone filmy na liście odtwarzania</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>Wyjdź</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation></translation>
    </message>
    <message>
        <source>Bye</source>
        <translation>Na razie</translation>
    </message>
    <message>
        <source>&amp;Website</source>
        <translation>Strona domo&amp;wa</translation>
    </message>
    <message>
        <source>%1 on the Web</source>
        <translation>Strona domowa %1</translation>
    </message>
    <message>
        <source>&amp;Donate via PayPal</source>
        <translation>&amp;Dotacja dla twórcy przez PayPal</translation>
    </message>
    <message>
        <source>Please support the continued development of %1</source>
        <translation>Proszę, wspomóż finansowo prace nad %1</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>O progr&amp;amie</translation>
    </message>
    <message>
        <source>Info about %1</source>
        <translation>Info o %1</translation>
    </message>
    <message>
        <source>&amp;Search</source>
        <translation type="obsolete">Szukaj</translation>
    </message>
    <message>
        <source>&amp;Application</source>
        <translation>Program</translation>
    </message>
    <message>
        <source>&amp;Playlist</source>
        <translation>Lista odtwarzania</translation>
    </message>
    <message>
        <source>&amp;Video</source>
        <translation>Film</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>Pomoc</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>Otwieranie %1</translation>
    </message>
    <message>
        <source>Fatal error: %1</source>
        <translation>Fatalny błąd: %1</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation>Błąd: %1</translation>
    </message>
    <message>
        <source>&amp;Play</source>
        <translation>&amp;Odtwarzaj</translation>
    </message>
    <message>
        <source>Resume playback</source>
        <translation>Wznów odtwarzanie</translation>
    </message>
    <message>
        <source>Exit &amp;Full Screen</source>
        <translation>Wyłącz &amp;pełny ekran</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation></translation>
    </message>
    <message>
        <source>Volume at %1%</source>
        <translation>Głośność %1%</translation>
    </message>
    <message>
        <source>Volume is muted</source>
        <translation>Dźwięk jest wyłączony</translation>
    </message>
    <message>
        <source>Volume is unmuted</source>
        <translation>Dźwięk jest włączony</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Szukaj</translation>
    </message>
    <message>
        <source>Mute volume</source>
        <translation>Wyłącz dźwięk</translation>
    </message>
    <message>
        <source>Press %1 to raise the volume, %2 to lower it</source>
        <translation>Wciśnij %1 aby zwiększyć głośność, %2 żeby ściszyć</translation>
    </message>
    <message>
        <source>Remaining time: %1</source>
        <translation>Pozostały czas: %1</translation>
    </message>
</context>
<context>
    <name>MediaView</name>
    <message>
        <source>Most relevant</source>
        <translation>Najbardziej trafne</translation>
    </message>
    <message>
        <source>Most recent</source>
        <translation>Najnowsze</translation>
    </message>
    <message>
        <source>Most viewed</source>
        <translation>Najpopularniejsze</translation>
    </message>
    <message>
        <source>You&apos;re watching &quot;%1&quot;</source>
        <translation>Oglądasz &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>NetworkAccess</name>
    <message>
        <source>Network error: %1</source>
        <translation>Błąd sieci: %1</translation>
    </message>
</context>
<context>
    <name>PrettyItemDelegate</name>
    <message>
        <source>%1 views</source>
        <translation>%1 wyświetleń</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Szukaj</translation>
    </message>
</context>
<context>
    <name>SearchView</name>
    <message>
        <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
        <translation>Witaj w &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
    </message>
    <message>
        <source>Enter a keyword to start watching videos.</source>
        <translation>Wpisz szukane słowo i zacznij oglądać filmy.</translation>
    </message>
    <message>
        <source>Watch</source>
        <translation>Wyświetl</translation>
    </message>
    <message>
        <source>Recent keywords</source>
        <translation>Ostatnio szukane</translation>
    </message>
    <message>
        <source>A new version of %1 is available. Please &lt;a href=&apos;%2&apos;&gt;update to version %3&lt;/a&gt;</source>
        <translation>Nowa wersja %1 jest dostępna. Proszę &lt;a href=&apos;%2&apos;&gt; zaktualizuj do wersji %3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Make yourself comfortable</source>
        <translation>Usiądź wygodnie</translation>
    </message>
</context>
<context>
    <name>SettingsView</name>
    <message>
        <source>Preferences</source>
        <translation>Opcje</translation>
    </message>
    <message>
        <source>&amp;Video options</source>
        <translation>Opcje &amp;obrazu</translation>
    </message>
    <message>
        <source>Use high quality video when available</source>
        <translation>Użyj wysokiej jakości wideo jeśli jest to możliwe</translation>
    </message>
    <message>
        <source>&amp;Saved recent keywords</source>
        <translation>&amp;Zapisz ostatnie słowa szukane</translation>
    </message>
    <message>
        <source>&amp;Clear recent keywords</source>
        <translation>&amp;Usuń ostatnie słowa szukane</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Zamknij</translation>
    </message>
</context>
<context>
    <name>Video</name>
    <message>
        <source>Network error: %1 for %2</source>
        <translation>Błąd sieci: %1 dla %2</translation>
    </message>
</context>
</TS>
